==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Armazenamento externo",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Conceder acesso",
    "Error configuring OAuth1" : "Erro ao configurar OAuth1",
    "Please provide a valid app key and secret." : "Por favor, indique um código e segredo de app válidos.",
    "Error configuring OAuth2" : "Erro ao configurar OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar chave par",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação NFD Mac (lenta)",
    "Enable encryption" : "Activar encriptação",
    "Enable previews" : "Ativar pré-visualizações",
    "Enable sharing" : "Ativar partilha",
    "Check for changes" : "Verificar se há alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez em cada acesso direto",
    "Read only" : "Apenas leitura",
    "Delete" : "Apagar",
    "Admin defined" : "Administrador definido",
    "Delete storage?" : "Apagar armazenamento?",
    "Saved" : "Guardado",
    "Saving..." : "A guardar...",
    "Save" : "Guardar",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please log out and in again to activate this mount point" : "Não foi possível aceder. Por favor faça logout e volte-se a autenticar para activar este ponto de montagem.",
    "Couldn't get the information from the remote server: {code} {type}" : "Não foi possível obter informação do servidor remoto: {código}{tipo}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível conseguir a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "external-storage" : "armazenamento externo",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Não fo possível obter lista de pontos de montagem de rede Windows: Resposta vazia do servidor",
    "Please enter the credentials for the {mount} mount" : "Por favor, introduza as credenciais para {mount}",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Credentials saved" : "Credenciais guardadas",
    "Credentials saving failed" : "Falha ao guardar as credenciais",
    "Credentials required" : "Credenciais necessárias",
    "Storage with ID \"%d\" not found" : "Armazenamento com ID \"%d\" não encontrado",
    "Invalid backend or authentication mechanism class" : "Parâmetros do mecanismo de autenticação inválidos",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Objectstore proibido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido utilizar a interface \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido utilizar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros backend insatisfeitos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros do mecanismo de autenticação inválidos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Armazenamento com ID \"%d\" não é evitável por utilizadores",
    "Access key" : "Chave de acesso",
    "Secret key" : "Código secreto",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "OAuth1" : "OAuth1",
    "App key" : "Chave da App",
    "App secret" : "Segredo da app",
    "OAuth2" : "OAuth2",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "Tenant name" : "Nome do locatário",
    "Identity endpoint URL" : "Identidade URL endpoint",
    "Domain" : "Domínio",
    "Rackspace" : "Rackspace",
    "API key" : "Chave API",
    "Global credentials" : "Credenciais globais",
    "Log-in credentials, save in database" : "Credenciais de Log-in, guardar na base de dados",
    "Username and password" : "Nome de utilizador e palavra-passe",
    "Log-in credentials, save in session" : "Credenciais de login, guardar na sessão",
    "User entered, store in database" : "Inseridos pelo utilizador, armazenar na base de dados",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "Legacy (v2) authentication" : "Autenticação obsoleta (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota ",
    "Secure https://" : "https:// Seguro",
    "FTP" : "FTP",
    "Host" : "Anfitrião",
    "Secure ftps://" : "ftps:// Seguro",
    "Local" : "Local",
    "Location" : "Localização:",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP com login por chave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Nome de utilizador como partilha",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Pedido expira (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporte cURL em PHP não está activo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporteF TP em PHP não está activo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "External storage support" : "Suporte para armazenamento externo",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "Open documentation" : "Abrir documentação",
    "Folder name" : "Nome da pasta",
    "External storage" : "Armazenamento Externo",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Advanced settings" : "Definições avançadas",
    "Allow users to mount external storage" : "Permitir que os utilizadores montem armazenamento externo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Armazenamento externo",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Conceder acesso",
    "Error configuring OAuth1" : "Erro ao configurar OAuth1",
    "Please provide a valid app key and secret." : "Por favor, indique um código e segredo de app válidos.",
    "Error configuring OAuth2" : "Erro ao configurar OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar chave par",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação NFD Mac (lenta)",
    "Enable encryption" : "Activar encriptação",
    "Enable previews" : "Ativar pré-visualizações",
    "Enable sharing" : "Ativar partilha",
    "Check for changes" : "Verificar se há alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez em cada acesso direto",
    "Read only" : "Apenas leitura",
    "Delete" : "Apagar",
    "Admin defined" : "Administrador definido",
    "Delete storage?" : "Apagar armazenamento?",
    "Saved" : "Guardado",
    "Save" : "Guardar",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please log out and in again to activate this mount point" : "Não foi possível aceder. Por favor faça logout e volte-se a autenticar para activar este ponto de montagem.",
    "Couldn't get the information from the remote server: {code} {type}" : "Não foi possível obter informação do servidor remoto: {código}{tipo}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível conseguir a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "external-storage" : "armazenamento externo",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Não fo possível obter lista de pontos de montagem de rede Windows: Resposta vazia do servidor",
    "Please enter the credentials for the {mount} mount" : "Por favor, introduza as credenciais para {mount}",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Credentials saved" : "Credenciais guardadas",
    "Credentials saving failed" : "Falha ao guardar as credenciais",
    "Credentials required" : "Credenciais necessárias",
    "Storage with ID \"%d\" not found" : "Armazenamento com ID \"%d\" não encontrado",
    "Invalid backend or authentication mechanism class" : "Parâmetros do mecanismo de autenticação inválidos",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Objectstore proibido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido utilizar a interface \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido utilizar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros backend insatisfeitos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros do mecanismo de autenticação inválidos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Armazenamento com ID \"%d\" não é evitável por utilizadores",
    "Access key" : "Chave de acesso",
    "Secret key" : "Código secreto",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "OAuth1" : "OAuth1",
    "App key" : "Chave da App",
    "App secret" : "Segredo da app",
    "OAuth2" : "OAuth2",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "Tenant name" : "Nome do locatário",
    "Identity endpoint URL" : "Identidade URL endpoint",
    "Domain" : "Domínio",
    "Rackspace" : "Rackspace",
    "API key" : "Chave API",
    "Global credentials" : "Credenciais globais",
    "Log-in credentials, save in database" : "Credenciais de Log-in, guardar na base de dados",
    "Username and password" : "Nome de utilizador e palavra-passe",
    "Log-in credentials, save in session" : "Credenciais de login, guardar na sessão",
    "User entered, store in database" : "Inseridos pelo utilizador, armazenar na base de dados",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "Legacy (v2) authentication" : "Autenticação obsoleta (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota ",
    "Secure https://" : "https:// Seguro",
    "FTP" : "FTP",
    "Host" : "Anfitrião",
    "Secure ftps://" : "ftps:// Seguro",
    "Local" : "Local",
    "Location" : "Localização:",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP com login por chave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Nome de utilizador como partilha",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Pedido expira (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporte cURL em PHP não está activo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "O suporteF TP em PHP não está activo ou instalado. Não é possível montar %s. Por favor peça ao seu administrador de sistema que o instale.",
    "External storage support" : "Suporte para armazenamento externo",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "Open documentation" : "Abrir documentação",
    "Folder name" : "Nome da pasta",
    "External storage" : "Armazenamento Externo",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Advanced settings" : "Definições avançadas",
    "Allow users to mount external storage" : "Permitir que os utilizadores montem armazenamento externo",
    "Saving..." : "A guardar..."
},
"nplurals=2; plural=(n != 1);");
